==> crypto-2.6.1.tgz: package/Qiwi/Qiwi.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const Qiwi = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 32 32"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M16 32C7.163 32 0 24.837 0 16S7.163 0 16 0s16 7.163 16 16-7.163 16-16 16zm6.59-12.555c-.025-.22-.152-.724-.482-.853-.165-.065-.305-.013-.368.103-.102.181-.026.53.165.84.19.311.368.466.495.466s.241-.155.19-.556zm-1.777.88c-.203-.182-.432-.272-.635-.272a.489.489 0 00-.407.18c-.228.285-.126.802.23 1.113.152.142.38.22.596.22a.663.663 0 00.52-.233c.204-.285.09-.672-.304-1.009zM7 14.894c0 4.912 3.91 8.894 8.734 8.894 1.283 0 2.552-.245 4.419-.259 1.663 0 3.491.595 5.497 2.405.203.181.47-.052.292-.271-1.968-2.547-3.796-3.025-5.624-3.44-2.235-.503-3.377-1.77-4.177-3.18-.153-.284-.229-.232-.242.13a8.078 8.078 0 00.115 1.59h-.267c-3.186 0-5.776-2.637-5.776-5.883C9.97 11.636 12.56 9 15.747 9s5.777 2.637 5.777 5.882c0 .233-.013.466-.038.686-.432-.078-1.257-.09-1.841-.039-.216.026-.19.129-.025.155 1.904.362 3.212 1.564 3.516 3.75.013.051.076.064.102.025a9.074 9.074 0 001.231-4.564C24.47 9.982 20.56 6 15.734 6 10.91 6 7 9.982 7 14.894z"
  }));
});
Qiwi.displayName = 'Qiwi';
export const QiwiDimensions = {
  height: 32,
  width: 32
};

==> crypto-2.7.1.tgz: package/Qiwi/Qiwi.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Qiwi = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 32 32"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M16 32C7.163 32 0 24.837 0 16S7.163 0 16 0s16 7.163 16 16-7.163 16-16 16zm6.59-12.555c-.025-.22-.152-.724-.482-.853-.165-.065-.305-.013-.368.103-.102.181-.026.53.165.84.19.311.368.466.495.466s.241-.155.19-.556zm-1.777.88c-.203-.182-.432-.272-.635-.272a.489.489 0 00-.407.18c-.228.285-.126.802.23 1.113.152.142.38.22.596.22a.663.663 0 00.52-.233c.204-.285.09-.672-.304-1.009zM7 14.894c0 4.912 3.91 8.894 8.734 8.894 1.283 0 2.552-.245 4.419-.259 1.663 0 3.491.595 5.497 2.405.203.181.47-.052.292-.271-1.968-2.547-3.796-3.025-5.624-3.44-2.235-.503-3.377-1.77-4.177-3.18-.153-.284-.229-.232-.242.13a8.078 8.078 0 00.115 1.59h-.267c-3.186 0-5.776-2.637-5.776-5.883C9.97 11.636 12.56 9 15.747 9s5.777 2.637 5.777 5.882c0 .233-.013.466-.038.686-.432-.078-1.257-.09-1.841-.039-.216.026-.19.129-.025.155 1.904.362 3.212 1.564 3.516 3.75.013.051.076.064.102.025a9.074 9.074 0 001.231-4.564C24.47 9.982 20.56 6 15.734 6 10.91 6 7 9.982 7 14.894z"
  }));
});
Qiwi.displayName = 'Qiwi';
export var QiwiDimensions = {
  height: 32,
  width: 32
};
